#[repr(u32)]pub enum DispatchPolicy {
ExclusiveTarget = 1,
TopHitAndAncestorsInTarget = 2,
MouseHoverAndLatchInTarget = 3,
}Expand description
A specification of the UI clients that may have injected events dispatched to them in an |Target|. One is specified in |Config|.
A useful concept is “latching”, where one or more clients may start receiving the pointer event stream, prior to assignment of stream ownership. After ownership is assigned (e.g., through a gesture disambiguation protocol), non-owning clients have their latch terminated – they stop receiving the pointer event stream.
- A client’s latch does not itself confer stream ownership (receiving the entire pointer event stream); gesture disambiguation or device termination may prematurely end the stream dispatched to that client.
- It’s possible for a client to latch while hidden from the user (i.e., manipulate a surface that is invisible to the user), where the occluding surface is owned by a client outside of |Target|. Conversely, these occluding clients cannot latch, because latched clients must be in |Target|’s view tree.
Variants